@@ -422,7 +422,9 @@ class UnitPrescription(Unit, metaclass=abc.ABCMeta):
             for item in operating_systems:
                 os_name = item.get("name")
                 os_version = item.get("version")
-                if os_name == os_used_name and os_version == os_used_version:
+                if (os_name is None or os_name == os_used_name) and (
+                    os_version is None or os_version == os_used_version
+                ):
                     _LOGGER.debug("%s: Matching operating system %r in version %r", unit_name, os_name, os_version)
                     break
             else:
